Module common

Module common 

Shared error characteristics for the error type generation process.

Structs

Format
The format string for an error’s Display implementation.
ImportRoot
The root of all imports for error-related types.
Param
A meta-parameter for an error type.
Transparent
A structure that determines transparence over a field.

Enums

FieldRef
A reference to a field in any structure.
ForwardSource
An enumeration that determines whether a field is the source of the error or not.
InlineOptions
The inline options for an error type.
ParamKind
The kind of meta-parameter.