ParamKind

Enum ParamKind 

pub enum ParamKind {
    Inline(InlineOptions),
    Import(ImportRoot),
    Format(Format),
    Source(FieldRef),
    Transparent(Transparent),
    From,
}
The kind of meta-parameter.

Variants



Inline(InlineOptions)

The inline behavior of the error type.



Import(ImportRoot)

The import root of the error type.



Format(Format)

The format string of the error type.



Source(FieldRef)

The source-forwarding behavior of the error type.



Transparent(Transparent)

A transparent error type.

This is useful for new-type wrappers that are transparent over some other type.



From

The from forwarding behavior of the error type.

This is useful for new-type wrappers that are completely opaque to the error type.