Param

Struct Param 

pub struct Param {
    pub name: Option<Ident>,
    pub kind: ParamKind,
}
A meta-parameter for an error type.

This is the conjuction of all meta-parameters that are used in the error type generation process.

This is used to parse the meta-parameters of an error type, to then be processed accordingly to the position in where they were found.

Fields

name: Option<Ident>

The identifier of the meta-parameter.

In most cases, this is the identifier which is used to identify which ParamKind to parse.

kind: ParamKind

The parameter kind of the meta-parameter.

Implementations

Source

impl Param

pub const fn lone(kind: ParamKind) -> Self

A new meta-parameter that has no specific name.

pub const fn identified(name: Ident, kind: ParamKind) -> Self

A new meta-parameter that has a specific name.

Source

impl Param

pub fn classify<'a>( iter: impl IntoIterator<Item = &'a Attribute>, ) -> Result<(Vec<Self>, Vec<&'a Attribute>)>

Classify an iterator of borrowed syn::Attributes into a list of Params where it is deemed possible.

Source

impl Param

pub fn attribute(target_meta: &Meta) -> Result<Self>

Attempt to parse a meta-parameter from a syn::Meta.

Note that will reinterpret the supplied syn::Meta as a Param using Param::parse.