pub struct Expand {}Expand description
A struct that encapsulates the code generation for error definitions.
Implementations
Sourceimpl Expand
impl Expand
Sourcepub fn structure(target_value: Structure) -> Result<TokenStream>
pub fn structure(target_value: Structure) -> Result<TokenStream>
Expand to the error implementation for the target Structure.
Sourcepub fn enumeration(target_value: Enumeration) -> Result<TokenStream>
pub fn enumeration(target_value: Enumeration) -> Result<TokenStream>
Expand to the error implementation for the target Enumeration.