pub fn generate(input: &DeriveInput) -> Result<TokenStream>Expand description
Parse, validate, and expand one derive input.
Errors
Returns the first syntax, semantic, or expansion diagnostic produced by the engine.
pub fn generate(input: &DeriveInput) -> Result<TokenStream>Parse, validate, and expand one derive input.
Returns the first syntax, semantic, or expansion diagnostic produced by the engine.