pub struct ValidatedTarget(/* private fields */);Expand description
A validated derive target that can be expanded safely.
Implementations
Sourceimpl ValidatedTarget
impl ValidatedTarget
Sourcepub fn expand(self) -> Result<TokenStream>
pub fn expand(self) -> Result<TokenStream>
Expand the validated target into Rust implementation tokens.
Errors
Returns a diagnostic if final token construction discovers an invalid generated Rust fragment.