The structure error type.
Structs
- Named
Field - A named field that is part of a structure.
- Structure
- A structure that corresponds to an error type.
- Unnamed
Field - An unnamed field that is part of a structure.
Enums
- Field
List - The field list of a structure.
- Structure
Options - The options for this structure in terms of its behavior.