FieldList

Enum FieldList 

pub enum FieldList {
    Named(Vec<NamedField>),
    Unnamed(Vec<UnnamedField>),
    Unit,
}
The field list of a structure.

Variants



Named(Vec<NamedField>)

A named field list, which is a list of fields that are named.



Unnamed(Vec<UnnamedField>)

An unnamed field list, which is a list of fields that are not named.



Unit

A unit field list, which is equivalent to an absence of fields.

Implementations

Source

impl FieldList

pub fn raw(fields: &Fields) -> Result<Self>

Convert a target syn::Fields into a FieldList.

pub fn exactly_one(fields: &Fields) -> Result<(FieldRef, Type)>

Expect exactly one field in the target syn::Fields.

pub fn pattern(&self) -> Result<TokenStream>

Compute an irrefutable pattern for this field list.