StructureOptions

Enum StructureOptions 

pub enum StructureOptions {
    Standalone {
        source_field: Option<FieldRef>,
        format_args: Format,
    },
    Transparent(Transparent),
    Forward {
        source_field: Option<FieldRef>,
        field_ref: FieldRef,
        field_type: Type,
        format_args: Format,
    },
}
The options for this structure in terms of its behavior.

Variants



Standalone

The structure is a new, standalone error type.

Fields

source_field: Option<FieldRef>

The field to be used as the source of the error.

format_args: Format

The format parameters for this structure.



Transparent(Transparent)

A structure that is transparent over some downstream type.



Forward

A structure that is a forwarder to one of its fields.

Fields

source_field: Option<FieldRef>

The field to be used as the source of the error.

field_ref: FieldRef

A reference to the field that is being forwarded.

field_type: Type

The type of the forwarded field.

format_args: Format

The format parameters for this structure.