Shared error characteristics for the error type generation process.
Structs
- Format
- The format string for an error’s
Displayimplementation. - Import
Root - The root of all imports for error-related types.
- Param
- A meta-parameter for an error type.
- Transparent
- A structure that determines transparence over a field.
Enums
- Field
Ref - A reference to a field in any structure.
- Forward
Source - An enumeration that determines whether a field is the source of the error or not.
- Inline
Options - The inline options for an error type.
- Param
Kind - The kind of meta-parameter.