pub enum FieldRef {
Named(Ident),
Indexed(usize),
}Expand description
A reference to a field in any structure.
Variants
Named(Ident)
A reference to a field by its distinctive name.
Indexed(usize)
A reference to an unnamed field by its index.