pub enum InlineOptions {
Neutral,
Never,
Always,
}Expand description
The inline options for an error type.
Variants
Neutral
Neutral inline behavior.
This will mark all implemented methods as #[inline], which will hint
the compiler to inline them if it deems it beneficial.
This is the default behavior.
Never
Never attempt to inline implemented methods for this error type.
Always
Always attempt to inline implemented methods for this error type.