pub struct Param {
pub name: Option<Ident>,
pub kind: ParamKind,
}Expand description
A meta-parameter for an error type.
This is the conjuction of all meta-parameters that are used in the error type generation process.
This is used to parse the meta-parameters of an error type, to then be processed accordingly to the position in where they were found.
Fields
name: Option<Ident>The identifier of the meta-parameter.
In most cases, this is the identifier which is used to identify which
ParamKind to parse.
kind: ParamKindThe parameter kind of the meta-parameter.
Implementations