Module structure

Module structure 

The structure error type.

Structs

NamedField
A named field that is part of a structure.
Structure
A structure that corresponds to an error type.
UnnamedField
An unnamed field that is part of a structure.

Enums

FieldList
The field list of a structure.
StructureOptions
The options for this structure in terms of its behavior.