pub enum StructureOptions {
Standalone {
source_field: Option<FieldRef>,
format_args: Format,
},
Transparent(Transparent),
Forward {
source_field: Option<FieldRef>,
field_ref: FieldRef,
field_type: Type,
format_args: Format,
},
}Expand description
The options for this structure in terms of its behavior.
Variants
Standalone
The structure is a new, standalone error type.
Fields
Transparent(Transparent)
A structure that is transparent over some downstream type.
Forward
A structure that is a forwarder to one of its fields.